@@ -14,7 +14,7 @@ except ImportError:
     import libsvg
     import libmd
 
-__version__ = 'v1.3.3'
+__version__ = 'v1.3.4'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook, output_xmind, \
@@ -40,6 +40,7 @@ class TranslateJson(object):
         self.history_offset = 0
         self.history_base = -1
         self.history_group = {}
+        self.group_set = []
         self.pre_group = ''
         self.all_reg_data = ''
         self.all_reg_tex_data = ''
@@ -162,9 +163,16 @@ class TranslateJson(object):
             self.history_addrr = base_addr
     
         group_path_list = self.get_group_path(dpath)
-        for i in group_path_list:
-            if i in self.history_group:
-                self.history_group[i]['num'] +=1
+        if len(group_path_list) > 0:
+            if group_path_list not in self.group_set:
+                self.group_set.append(group_path_list)
+                for i in group_path_list:
+                    if i in self.history_group:
+                        self.history_group[i]['num'] +=1
+            else:
+                i = group_path_list[-1]
+                if i in self.history_group:
+                    self.history_group[i]['num'] +=1
         if group_path_list != []:
             group_path = group_path_list[-1]
         else:
